import React, { useState, useContext, useEffect } from 'react'
import { MenuItem, Select, Divider } from '@mui/material'
import JarvisWedgit from "../../../components/jarvisWedgit/index"
import { t as _translate } from "i18next"
import { CargoReleaseContext } from "../cargoReleaseContext"
import Table from "@mui/material/Table";
import TableBody from "@mui/material/TableBody";
import TableCell from "@mui/material/TableCell";
import TableContainer from "@mui/material/TableContainer";
import TableHead from "@mui/material/TableHead";
import TableRow from "@mui/material/TableRow";
import Paper from "@mui/material/Paper";
import { Box } from "@mui/system";
import { CircularProgress } from "@mui/material";
import axios from '../../../config/axios/axios'
import { muiCoustomStyles } from "../../../assets/css/muiStyles";
import Button from "@mui/material/Button";

import Dialog from '@mui/material/Dialog';
import FormControl from "@mui/material/FormControl";
import TextField from "@mui/material/TextField";
import FormGroup from '@mui/material/FormGroup';
import FormControlLabel from '@mui/material/FormControlLabel';
import Checkbox from '@mui/material/Checkbox';
import ActionToolBar from "../../../components/ActionToolBar/actionToolBar"
import Snackbar from '@mui/material/Snackbar';
import MuiAlert from '@mui/material/Alert';
export default function PermitsDetails() {
    const Alert = React.forwardRef(function Alert(props, ref) {
        return <MuiAlert elevation={6} ref={ref} variant="filled" {...props} />;
    });
    const clasess = muiCoustomStyles();

    const cargoReleaseContext = useContext(CargoReleaseContext)
    const [cargoReleaseDetails, setCargoReleaseDetails] = useState(null)
    const [detailsLoadingIndicator, setDetailsLoadingIndicator] = useState(false)
    const [sharesLoadingIndicator, setSharesLoadingIndicator] = useState(false)
    const [cargoReleaseShares, setCargoReleaseShares] = useState(false)
    const [showTruncatedModal, setShowTruncatedModal] = useState(false)
    const [projectTc, setProjectTc] = useState(null)
    const [selectedToCompany, setSelectedToCompany] = useState(null)
    const [selectedFromCompany, setSelectedFromCompany] = useState(null)

    const [numberOfShares, setNumberOfShares] = useState("")
    const [reassigneShares, setReassigneShares] = useState(false)
    const [createCargoReleaseLoadingIndicator, setCreateCargoReleaseLoadingIndicator] = useState(false)
    const [refresh, setRefresh] = useState(false)
    const [alertMessage, setAlertMessage] = useState(null)
    const [openAlert, setOpenAlert] = useState(false)
    const [maxNumberOfShares, setMaxNumberOfShares] = useState(null)
    const [showIncreaseModal, setShowIncreaseModal] = useState(false)
    const [numberOfAddedShares, setNumberOfAddedShares] = useState("")
    const [notes, setNotes] = useState("")
    const [addMoreSharesLoadingIndicator, setAddMoreSharesLoadingIndicator] = useState(false)
    const [zeroSharesLoadingIndicator, setZeroSharesLoadingIndicator] = useState(false)
    const [showZeroModal, setShowZeroModal] = useState(false)
    const [showActivationModal, setShowActivationModal] = useState(false)
    const [reassigneSharesForAvtivation, setReassigneSharesForAvtivation] = useState(false)
    const [numberOfSharesForActivation, setNumberOfSharesForActivation] = useState("")
    const [cancelSharesLoadingIndicator, setCancelSharesLoadingIndicator] = useState(false)
    const [showCancelModal, setShowCancelModal] = useState(false)
    const [selectedCompanyForActivation, setSelectedCompanyForActivation] = useState(null)
    const [activateCargoReleaseLoadingIndicator, setActivateCargoReleaseLoadingIndicator] = useState(false)
    const [projectTcFrom , setProjectTcFrom]=useState(null)
    useEffect(() => {
        if (cargoReleaseContext.selectedCargoRelease && !detailsLoadingIndicator && !sharesLoadingIndicator) {
            setDetailsLoadingIndicator(true)
            let params = {
                method: "getCargoRelease",
                id: cargoReleaseContext.selectedCargoRelease
            }
            axios.get("/permit", { params: params }).then(res => {
                setCargoReleaseDetails(res.data)
                setDetailsLoadingIndicator(false)

            }).catch(error => {
                setDetailsLoadingIndicator(false)
                setOpenAlert(true)
                setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
            })

            let params2 = {
                method: "searchCargoReleaseShare",
                filter: { cargo_release_id: cargoReleaseContext.selectedCargoRelease }

            }
            params2.filter = JSON.stringify(params2.filter)
            setSharesLoadingIndicator(true)
            axios.get("/permit", { params: params2 }).then(res => {
                setSharesLoadingIndicator(false)
                setCargoReleaseShares(res.data.data)
            }).catch(error => {
                setSharesLoadingIndicator(false)
                setOpenAlert(true)
                setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
            })

            let params3 = {
                method: "searchAllProjectTc"
            }
            axios.get("/permit", { params: params3 }).then(res => {
                setProjectTc(res.data.data)
            }).catch(error => {
                console.log(error)
                setOpenAlert(true)
                setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
            })

            let params4 = {
                method: "searchCargoReleaseInvolvedParties",
                cargo_release_id: cargoReleaseContext.selectedCargoRelease
            }
            axios.get("/permit", { params: params4 }).then(res => {
                setProjectTcFrom(res.data.data)
            }).catch(error => {
                console.log(error)
                setOpenAlert(true)
                setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
            })


        } else {
            setCargoReleaseDetails(null)
        }

    }, [cargoReleaseContext.selectedCargoRelease, refresh])

    const onCloseAlert = () => {
        setOpenAlert(false)
    }

    const activateCargoRelease = () => {

        if ((selectedCompanyForActivation ? !selectedCompanyForActivation.value : true) || !numberOfSharesForActivation) {
            setOpenAlert(true)
            setAlertMessage({ message: _translate("cargo_release.details.activation_modal.activation_erro_message"), type: "warning" })
            return
        }


        setActivateCargoReleaseLoadingIndicator(true)

        let params = {
            method: "reqCR",
            id: cargoReleaseContext.selectedCargoRelease,
            project_tc_id: selectedCompanyForActivation ? selectedCompanyForActivation.value : null,
            is_reassign: reassigneSharesForAvtivation ==false ? 0 : 1,
            shares: numberOfSharesForActivation
        }

        axios.get("permit", { params: params }).then(res => {
            setActivateCargoReleaseLoadingIndicator(false)
            setShowActivationModal(false)
            resetActivationModalFeilds()
            setOpenAlert(true)
            setAlertMessage({ message: _translate("cargo_release.details.active_carg_release_response_message"), type: "success" })
        }).catch(error => {
            setActivateCargoReleaseLoadingIndicator(false)
            setOpenAlert(true)
            setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
        })
        // /permit?method=reqCR&id=9&project_tc_id=2&is_reassign=1&shares=10

    }

    const createCargoRelease = () => {
        if ((selectedToCompany ? !selectedToCompany.value : true) || !numberOfShares || (selectedFromCompany ? !selectedFromCompany.value : true)) {
            setOpenAlert(true)
            setAlertMessage({ message: _translate("cargo_release.details.truncated_shares_modal.truncated_erro_message"), type: "warning" })
            return
        }
        setCreateCargoReleaseLoadingIndicator(true)
        let params = {
            method: "reassignShare",
            cargo_release_id: cargoReleaseDetails.id,
            share_id: "1000",
            shares: [
                {
                    project_tc_id: selectedToCompany ? selectedToCompany.value : null,
                    from: selectedFromCompany ? selectedFromCompany.value : null,
                    count: numberOfShares,

                }
            ]
        }
        // params.shares = JSON.stringify(params.shares)
        axios.post("/permit", params).then(res => {
            console.log(params, "params")
            setShowTruncatedModal(false)
            resetModalFeild()
            setCreateCargoReleaseLoadingIndicator(false)
            setOpenAlert(true)
            setAlertMessage({ message: _translate("cargo_release.details.truncated_cargo_release_response"), type: "success" })
        }).catch(error => {
            console.log(error)
            setCreateCargoReleaseLoadingIndicator(false)
            setOpenAlert(true)
            setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
        })

    }

    const addMoreShares = () => {
        if ((!numberOfAddedShares)) {
            setOpenAlert(true)
            setAlertMessage({ message: _translate("cargo_release.details.increase_shares_modal.increase_erro_message"), type: "warning" })
            return
        }
        setAddMoreSharesLoadingIndicator(true)

        let params = {
            method: "",
            number: numberOfAddedShares,
            notes: notes
        }

        axios.get("/permit", { params: params }).then(res => {
            setAddMoreSharesLoadingIndicator(false)
            resetIncreaseModalFeild()
            setOpenAlert(true)
            setAlertMessage({ message: _translate("cargo_release.details.increse_shares_response_message"), type: "success" })
            setShowIncreaseModal(false)
        }).catch(error => {

            setAddMoreSharesLoadingIndicator(false)
            setOpenAlert(true)
            setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
        })
    }

    const zeroShares = () => {
        setZeroSharesLoadingIndicator(true)
        let params = {
            method: ""
        }
        axios.get("/permit", { params: params }).then(res => {
            setZeroSharesLoadingIndicator(false)
            setShowZeroModal(false)
            setOpenAlert(true)
            setAlertMessage({ message: _translate("cargo_release.details.zero_shares_response"), type: "success" })
        }).catch(error => {
            setZeroSharesLoadingIndicator(false)
            setOpenAlert(true)
            setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
        })
    }


    const cancelShares = () => {
        setCancelSharesLoadingIndicator(true)
        let params = {
            method: ""
        }
        axios.get("/permit", { params: params }).then(res => {
            setCancelSharesLoadingIndicator(false)
            setShowCancelModal(false)
            setOpenAlert(true)
            setAlertMessage({ message: _translate("cargo_release.details.cancel_shares_response"), type: "success" })
        }).catch(error => {
            setCancelSharesLoadingIndicator(false)
            setOpenAlert(true)
            setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
        })
    }

    const resetActivationModalFeilds = () => {
        setNumberOfSharesForActivation("")
        setSelectedCompanyForActivation(null)
        setReassigneSharesForAvtivation(false)
    }
    const resetModalFeild = () => {
        setSelectedToCompany(null)
        setSelectedFromCompany(null)

        setNumberOfShares("")
        setReassigneShares(false)
    }
    const resetIncreaseModalFeild = () => {
        setNumberOfAddedShares("")
        setNotes("")
    }
    const onRefresh = () => {
        setRefresh(!refresh)
    }
    return (
        <div className="jarvisBody__contiener"
            style={{ height: window.innerHeight - 50, margin: "0", width: "100%" }}>
            <Snackbar open={openAlert} autoHideDuration={6000} onClose={onCloseAlert}>
                <Alert severity={alertMessage ? alertMessage.type : null} sx={{ width: '100%' }}>
                    {alertMessage ? alertMessage.message : ""}
                </Alert>
            </Snackbar>

            <JarvisWedgit editbutton={false} deletebutton={false} colorbutton={false}
                togglebutton={false} fullscreenbutton={false} color="blueDark">

                <header className='mainJarvisWedgit__header'>
                    <div className='jarvisWedgit__title fontMedium' >
                        {_translate("permit.cargo_release.details.title")}
                    </div>

                    {
                        cargoReleaseDetails &&

                        <ActionToolBar

                            onRefresh={onRefresh}
                            object_code={"TCS.CARGO_RELEASE"}
                            object_bean={cargoReleaseDetails}
                            onUpdate={() => {
                                setShowTruncatedModal(true)
                                resetModalFeild()
                            }}
                            onIncrease={() => {
                                setShowIncreaseModal(true)
                                resetIncreaseModalFeild()
                            }}
                            onPlus={() => {
                                alert("test")
                            }}
                            onChangeStatus={(statusTo) => {
                                if (statusTo == "CLOSED") {
                                    setShowZeroModal(true)
                                } else if (statusTo == "INACTIVE") {
                                    setShowCancelModal(true)
                                } else if (statusTo == "PENDING") {
                                    resetActivationModalFeilds()
                                    setShowActivationModal(true)
                                }
                            }}
                            customIcons={[
                                { icon: "fa-solid fa-arrow-up-right-dots", action_code: "UPDATE", callBack: "onIncrease", caption: _translate("cargo_release.details.action_tool_bar.increase_icon_tooltip") },
                                // { icon: "fa-solid fa-arrow-up-right-dots", action_code: "CHANGE_STATUS", object_new_status_code:"INACTIVE", callBack: "onChangeStatus" }
                                // { icon: "fa-solid fa-arrow-up-right-dots", user_role: "MENAGATE_OPERATION", callBack: "onPlus" }

                            ]}
                        />

                    }

                </header>

                {
                    <div style={{ fontWeight: 900 }}>


                        {cargoReleaseContext.selectedCargoRelease ?
                            (
                                detailsLoadingIndicator || sharesLoadingIndicator || !projectTc ?

                                    <Box
                                        sx={{
                                            display: "flex",
                                            justifyContent: "center",
                                            alignItems: "center",
                                            height: "75vh",
                                        }}
                                    >
                                        <CircularProgress />
                                    </Box>
                                    :
                                    <>
                                        {
                                            cargoReleaseDetails && cargoReleaseShares ?
                                                <>


                                                    <div className="col-md-12 col-sm-12 col-lg-12 col-xs-12 p-0 d-flex mt-3">
                                                        <div className="col-md-6 col-sm-6 col-lg-6 col-xs-6 p-0 d-flex justify-content-center">
                                                            <div>
                                                                {" "}
                                                                {_translate(
                                                                    "permit.cargo_release.details.cargo_release_number"
                                                                )}
                                                                :
                                                            </div>
                                                            <div className="px-2">{cargoReleaseDetails.serial}</div>
                                                        </div>

                                                        <div className="col-md-6 col-sm-6 col-lg-6 col-xs-6 p-0  d-flex justify-content-center">
                                                            <div>
                                                                {_translate(
                                                                    "permit.cargo_release.details.cargo_release_status"
                                                                )}{" "}
                                                                :
                                                            </div>
                                                            <div className="px-2">
                                                                {_translate(`cargo_release.list.card.statues.${cargoReleaseDetails.status}`)}
                                                            </div>
                                                        </div>
                                                    </div>

                                                    <div className="col-md-12 col-sm-12 col-lg-12 col-xs-12 p-0 d-flex mt-3">
                                                        <div className="col-md-6 col-sm-6 col-lg-6 col-xs-6 p-0  d-flex justify-content-center">
                                                            <div>
                                                                {_translate(
                                                                    "permit.cargo_release.details.issuer"
                                                                )}
                                                                :
                                                            </div>
                                                            <div className="px-2">{cargoReleaseDetails.details ? cargoReleaseDetails.details.issuer : ""}</div>
                                                        </div>

                                                        <div className="col-md-6 col-sm-6 col-lg-6 col-xs-6  p-0 d-flex justify-content-center">
                                                            <div>
                                                                {" "}
                                                                {_translate(
                                                                    "permit.cargo_release.details.create_date"
                                                                )}{" "}
                                                                :
                                                            </div>
                                                            <div className="px-2">{(cargoReleaseDetails.create_date).slice(0, 10)}</div>
                                                        </div>
                                                    </div>




                                                    <Divider
                                                        sx={{
                                                            borderWidth: "0.15rem",
                                                            margin: "1.5% auto",
                                                            width: "90%",
                                                        }}
                                                        flexItem
                                                    />



                                                    <div className="col-md-12 col-sm-12 col-lg-12 col-xs-12 d-flex mt-3">
                                                        <TableContainer
                                                            sx={{
                                                                maxHeight: "75vh",
                                                                overflowY: "auto",
                                                            }}
                                                            component={Paper}
                                                        >
                                                            <Table

                                                                size="small"
                                                                aria-label="a dense table"
                                                            >
                                                                <TableHead className={clasess.tabelHeaderCell}>
                                                                    <TableRow>
                                                                        <TableCell align="center">{_translate("cargo_release.details.table.company")}</TableCell>
                                                                        <TableCell align="center">{_translate("cargo_release.details.table.shares")}</TableCell>
                                                                        <TableCell align="center">{_translate("cargo_release.details.table.used_shares")}</TableCell>
                                                                        {/* <TableCell align="center">{_translate("cargo_release.details.table.is_reassign")}</TableCell> */}
                                                                    </TableRow>
                                                                </TableHead>
                                                                <TableBody >
                                                                    {cargoReleaseShares.map((ele) => (
                                                                        <TableRow
                                                                            key={ele.companyNAme}
                                                                            sx={{
                                                                                "&:last-child td, &:last-child th": {
                                                                                    border: 0,
                                                                                },
                                                                            }}
                                                                        >
                                                                            <TableCell align="center">{ele.tc_name}</TableCell>
                                                                            <TableCell align="center">{ele.shares}</TableCell>
                                                                            <TableCell align="center">{ele.used_share}</TableCell>
                                                                            {/* {
                                                                                ele.is_reassign == 1 ?
                                                                                    <TableCell align="center"><i style={{ color: "#75aa75" }} class="fa-solid fa-circle-check"></i></TableCell>
                                                                                    :
                                                                                    <TableCell align="center"><i style={{ color: "#ee9090" }} class="fa-solid fa-circle-xmark"></i></TableCell>
                                                                            } */}
                                                                        </TableRow>
                                                                    ))}
                                                                </TableBody>
                                                            </Table>
                                                        </TableContainer>
                                                    </div>

                                                    <Dialog
                                                        sx={{
                                                            '& .MuiDialog-paperWidthSm': {
                                                                maxWidth: "50%",
                                                                width: "30%",
                                                                minWidth: "650px",
                                                            }

                                                        }}

                                                        onClose={() => { setShowTruncatedModal(false) }} open={showTruncatedModal}>
                                                        <JarvisWedgit editbutton={false} deletebutton={false} colorbutton={false}
                                                            togglebutton={false} fullscreenbutton={false} color="blueDark">

                                                            <header className='mainJarvisWedgit__header'>
                                                                <div className='jarvisWedgit__title fontMedium' style={{ width: "100%", textAlign: "start" }}>
                                                                    {_translate("cargo_release.details.truncated_shares_modal.title")}
                                                                </div>

                                                            </header>

                                                            <div>
                                                                {
                                                                    cargoReleaseDetails && cargoReleaseDetails.shares ?
                                                                        <>
                                                                            <div className="d-flex align-items-center m-3">
                                                                                <div className="col-xs-5 col-sm-5 col-md-5 col-lg-5 autoCompleteLabel">
                                                                                    {_translate(
                                                                                        "cargo_release.details.truncated_shares_modal.from_company"
                                                                                    )} :
                                                                                </div>
                                                                                <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                                    <FormControl fullWidth>
                                                                                        <Select
                                                                                            className={clasess.mui_select}
                                                                                            value={selectedFromCompany ? selectedFromCompany.value : ""}
                                                                                            onChange={(event) => {

                                                                                                let project_tc_exist_in_shares = false
                                                                                                cargoReleaseShares.forEach(ele => {
                                                                                                    if (ele.share_project_tc_id == event.target.value) {
                                                                                                        project_tc_exist_in_shares = true
                                                                                                        setMaxNumberOfShares(ele.shares)
                                                                                                    }
                                                                                                })
                                                                                                if (!project_tc_exist_in_shares) {
                                                                                                    setMaxNumberOfShares(null)
                                                                                                }

                                                                                                setSelectedFromCompany(event.target)
                                                                                                console.log(event.target.value, "event.target")
                                                                                            }}
                                                                                        >
                                                                                            {projectTcFrom ?
                                                                                                projectTcFrom.map((ele) => {
                                                                                                    return (
                                                                                                        <MenuItem value={ele.id} name={ele.name} >
                                                                                                            {ele.name}
                                                                                                        </MenuItem>
                                                                                                    );
                                                                                                })
                                                                                                : null}
                                                                                        </Select>
                                                                                    </FormControl>
                                                                                </Box>
                                                                            </div>

                                                                            <div className="d-flex align-items-center m-3">
                                                                                <div className="col-xs-5 col-sm-5 col-md-5 col-lg-5 autoCompleteLabel">
                                                                                    {_translate(
                                                                                        "cargo_release.details.truncated_shares_modal.to_company"
                                                                                    )} :
                                                                                </div>
                                                                                <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                                    <FormControl fullWidth>
                                                                                        <Select
                                                                                            className={clasess.mui_select}
                                                                                            value={selectedToCompany ? selectedToCompany.value : ""}
                                                                                            onChange={(event) => {

                                                                                                setSelectedToCompany(event.target)
                                                                                                console.log(event.target, "event.target")
                                                                                            }}
                                                                                        >
                                                                                            {projectTc ?
                                                                                                projectTc.map((ele) => {
                                                                                                    return (
                                                                                                        <MenuItem value={ele.id} name={ele.name}>
                                                                                                            {ele.name}
                                                                                                        </MenuItem>
                                                                                                    );
                                                                                                })
                                                                                                : null}
                                                                                        </Select>
                                                                                    </FormControl>
                                                                                </Box>
                                                                            </div>


                                                                            <div className="d-flex align-items-center m-3">
                                                                                <div className="col-xs-5 col-sm-5 col-md-5 col-lg-5  autoCompleteLabel">
                                                                                    {_translate(
                                                                                        "cargo_release.details.truncated_shares_modal.shares"
                                                                                    )} :
                                                                                </div>
                                                                                <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                                    <FormControl fullWidth>
                                                                                        <TextField

                                                                                            size="small"
                                                                                            onChange={(event) => {
                                                                                                console.log(event.target.value)
                                                                                                if (isNaN(Number(event.target.value))) {
                                                                                                    setNumberOfShares(numberOfShares)
                                                                                                }
                                                                                                else if (event.target.value > cargoReleaseDetails.shares) {
                                                                                                    setNumberOfShares(cargoReleaseDetails.shares)
                                                                                                } else {
                                                                                                    setNumberOfShares(event.target.value)
                                                                                                }




                                                                                            }}
                                                                                            onBlur={(event) => { }}
                                                                                            value={numberOfShares}
                                                                                        />
                                                                                    </FormControl>

                                                                                </Box>


                                                                            </div>


                                                                            {maxNumberOfShares ?
                                                                                <div className="d-flex align-items-center m-3 mt-0">
                                                                                    <div className="col-xs-10 col-sm-10 col-md-10 col-lg-10   autoCompleteLabel">
                                                                                        <span className='star_class' >*</span>
                                                                                        {`${_translate("cargo_release.details.truncated_shares_modal.max_number_of_share_label")}  ${maxNumberOfShares}`}
                                                                                    </div>
                                                                                </div>
                                                                                : null}
                                                                        </>

                                                                        :

                                                                        <>
                                                                            <div className="d-flex align-items-center m-3">
                                                                                <div className="col-xs-12 col-sm-12 col-md-12 col-lg-12  autoCompleteLabel">
                                                                                    {_translate(
                                                                                        "cargo_release.details.truncated_shares_modal.no_shares_message"
                                                                                    )}
                                                                                </div>
                                                                            </div>
                                                                        </>
                                                                }
                                                            </div>
                                                            <div>


                                                                {/* {
                                                                    cargoReleaseDetails.details ?
                                                                        (
                                                                            cargoReleaseDetails.details.is_reassign == 1 ?
                                                                                <FormGroup >
                                                                                    <FormControlLabel className=' mt-1 ml-3 mr-3 mb-3 ' control={<Checkbox onChange={(e) => setReassigneShares(e.target.checked)} />} label={_translate("cargo_release.details.truncated_shares_modal.reassign")} sx={{ fontWeight: 900 }} />
                                                                                </FormGroup>
                                                                                : null
                                                                        )
                                                                        : null
                                                                } */}


                                                                <div className=" col-xs-12 col-sm-12 col-md-12 col-lg-12  d-flex " style={{ justifyContent: "space-evenly", marginBottom: "2%" }}>
                                                                    {

                                                                        createCargoReleaseLoadingIndicator ?
                                                                            <Box
                                                                                sx={{
                                                                                    display: "flex",
                                                                                    justifyContent: "center",
                                                                                    alignItems: "center",
                                                                                    // height: "75vh",
                                                                                }}
                                                                            >
                                                                                <CircularProgress />
                                                                            </Box>
                                                                            :
                                                                            <>
                                                                                {
                                                                                    cargoReleaseDetails && cargoReleaseDetails.shares &&
                                                                                    <Button
                                                                                        sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                        variant="contained"
                                                                                        className=" mt-1"
                                                                                        onClick={() => {
                                                                                            createCargoRelease()
                                                                                        }}
                                                                                    >
                                                                                        {" "}
                                                                                        {_translate("cargo_release.details.truncated_shares_modal.truncated")}
                                                                                    </Button>
                                                                                }


                                                                                <Button
                                                                                    sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                    variant="contained"
                                                                                    className=" mt-1"
                                                                                    color="error"
                                                                                    onClick={() => {
                                                                                        setShowTruncatedModal(false)
                                                                                        resetModalFeild()
                                                                                    }}
                                                                                >
                                                                                    {" "}
                                                                                    {_translate("cargo_release.details.truncated_shares_modal.cancel")}
                                                                                </Button>
                                                                            </>
                                                                    }


                                                                </div>
                                                            </div>
                                                        </JarvisWedgit>

                                                    </Dialog>


                                                    {/* ==================================================================================================================== */}

                                                    <Dialog
                                                        sx={{
                                                            '& .MuiDialog-paperWidthSm': {
                                                                maxWidth: "50%",
                                                                width: "30%",
                                                                minWidth: "650px",
                                                            }

                                                        }}

                                                        onClose={() => { setShowIncreaseModal(false) }} open={showIncreaseModal}>
                                                        <JarvisWedgit editbutton={false} deletebutton={false} colorbutton={false}
                                                            togglebutton={false} fullscreenbutton={false} color="blueDark">

                                                            <header className='mainJarvisWedgit__header'>
                                                                <div className='jarvisWedgit__title fontMedium' style={{ width: "100%", textAlign: "start" }}>
                                                                    {_translate("cargo_release.details.increse_shares_modal.title")}
                                                                </div>

                                                            </header>

                                                            <div>
                                                                {
                                                                    cargoReleaseDetails && cargoReleaseDetails.shares ?
                                                                        <>
                                                                            <div className="d-flex align-items-center m-3">
                                                                                <div className="col-xs-5 col-sm-5 col-md-5 col-lg-5  autoCompleteLabel">
                                                                                    {_translate(
                                                                                        "cargo_release.details.increase_shares_modal.shares"
                                                                                    )} :
                                                                                </div>
                                                                                <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                                    <FormControl fullWidth>
                                                                                        <TextField

                                                                                            size="small"
                                                                                            onChange={(event) => {
                                                                                                console.log(event.target.value)
                                                                                                if (isNaN(Number(event.target.value))) {
                                                                                                    setNumberOfAddedShares(numberOfAddedShares)
                                                                                                }
                                                                                                else {
                                                                                                    setNumberOfAddedShares(event.target.value)
                                                                                                }

                                                                                            }}
                                                                                            onBlur={(event) => { }}
                                                                                            value={numberOfAddedShares}
                                                                                        />
                                                                                    </FormControl>

                                                                                </Box>



                                                                            </div>

                                                                            <div className="d-flex align-items-center m-3">
                                                                                <div className="col-xs-5 col-sm-5 col-md-5 col-lg-5  autoCompleteLabel">
                                                                                    {_translate(
                                                                                        "cargo_release.details.increase_shares_modal.notes"
                                                                                    )} :
                                                                                </div>
                                                                                <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                                    <FormControl fullWidth>
                                                                                        <TextField

                                                                                            size="small"
                                                                                            onChange={(event) => {
                                                                                                setNotes(event.target.value)
                                                                                            }}
                                                                                            onBlur={(event) => { }}
                                                                                            value={notes}
                                                                                        />
                                                                                    </FormControl>

                                                                                </Box>



                                                                            </div>
                                                                        </>
                                                                        :
                                                                        <>
                                                                            <div className="d-flex align-items-center m-3">
                                                                                <div className="col-xs-12 col-sm-12 col-md-12 col-lg-12  autoCompleteLabel">
                                                                                    {_translate(
                                                                                        "cargo_release.details.increase_shares_modal.no_shares_message"
                                                                                    )}
                                                                                </div>
                                                                            </div>
                                                                        </>
                                                                }

                                                                <div className=" col-xs-12 col-sm-12 col-md-12 col-lg-12  d-flex " style={{ justifyContent: "space-evenly", marginBottom: "2%" }}>
                                                                    {

                                                                        addMoreSharesLoadingIndicator ?
                                                                            <Box
                                                                                sx={{
                                                                                    display: "flex",
                                                                                    justifyContent: "center",
                                                                                    alignItems: "center",
                                                                                    // height: "75vh",
                                                                                }}
                                                                            >
                                                                                <CircularProgress />
                                                                            </Box>
                                                                            :
                                                                            <>

                                                                                {
                                                                                    cargoReleaseDetails && cargoReleaseDetails.shares &&
                                                                                    <Button
                                                                                        sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                        variant="contained"
                                                                                        className=" mt-1"
                                                                                        onClick={() => {
                                                                                            addMoreShares()
                                                                                        }}
                                                                                    >
                                                                                        {" "}
                                                                                        {_translate("cargo_release.details.increase_shares_modal.increase")}
                                                                                    </Button>
                                                                                }


                                                                                <Button
                                                                                    sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                    variant="contained"
                                                                                    className=" mt-1"
                                                                                    color="error"
                                                                                    onClick={() => {
                                                                                        setShowIncreaseModal(false)
                                                                                        resetIncreaseModalFeild()
                                                                                    }}
                                                                                >
                                                                                    {" "}
                                                                                    {_translate("cargo_release.details.increase_shares_modal.cancel")}
                                                                                </Button>
                                                                            </>
                                                                    }


                                                                </div>
                                                            </div>
                                                        </JarvisWedgit>

                                                    </Dialog>
                                                    {/* ======================================================================================================================== */}












                                                    <Dialog
                                                        sx={{
                                                            '& .MuiDialog-paperWidthSm': {
                                                                maxWidth: "50%",
                                                                width: "30%",
                                                                minWidth: "650px",
                                                            }

                                                        }}

                                                        onClose={() => { setShowZeroModal(false) }} open={showZeroModal}>
                                                        <JarvisWedgit editbutton={false} deletebutton={false} colorbutton={false}
                                                            togglebutton={false} fullscreenbutton={false} color="blueDark">

                                                            <header className='mainJarvisWedgit__header'>
                                                                <div className='jarvisWedgit__title fontMedium' style={{ width: "100%", textAlign: "start" }}>
                                                                    {_translate("cargo_release.details.zero_shares_modal.title")}
                                                                </div>

                                                            </header>

                                                            <div>

                                                                <div className="d-flex align-items-center m-3">
                                                                    <div className="col-xs-12 col-sm-12 col-md-12 col-lg-12  autoCompleteLabel">
                                                                        {_translate(
                                                                            "cargo_release.details.zero_shares_modal.confirmation_message"
                                                                        )}
                                                                    </div>
                                                                    {/* <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                        <FormControl fullWidth>
                                                                            <TextField

                                                                                size="small"
                                                                                onChange={(event) => {
                                                                                    console.log(event.target.value)
                                                                                    if (isNaN(Number(event.target.value))) {
                                                                                        setNumberOfAddedShares(numberOfAddedShares)
                                                                                    }
                                                                                    else {
                                                                                        setNumberOfAddedShares(event.target.value)
                                                                                    }

                                                                                }}
                                                                                onBlur={(event) => { }}
                                                                                value={numberOfAddedShares}
                                                                            />
                                                                        </FormControl>

                                                                    </Box> */}



                                                                </div>


                                                                <div className=" col-xs-12 col-sm-12 col-md-12 col-lg-12  d-flex " style={{ justifyContent: "space-evenly", marginBottom: "2%" }}>
                                                                    {

                                                                        zeroSharesLoadingIndicator ?
                                                                            <Box
                                                                                sx={{
                                                                                    display: "flex",
                                                                                    justifyContent: "center",
                                                                                    alignItems: "center",
                                                                                    // height: "75vh",
                                                                                }}
                                                                            >
                                                                                <CircularProgress />
                                                                            </Box>
                                                                            :
                                                                            <>
                                                                                <Button
                                                                                    sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                    variant="contained"
                                                                                    className=" mt-1"
                                                                                    onClick={() => {
                                                                                        zeroShares()
                                                                                    }}
                                                                                >
                                                                                    {" "}
                                                                                    {_translate("cargo_release.details.zero_shares_modal.zero")}
                                                                                </Button>

                                                                                <Button
                                                                                    sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                    variant="contained"
                                                                                    className=" mt-1"
                                                                                    color="error"
                                                                                    onClick={() => {
                                                                                        setShowZeroModal(false)
                                                                                    }}
                                                                                >
                                                                                    {" "}
                                                                                    {_translate("cargo_release.details.zero_shares_modal.cancel")}
                                                                                </Button>
                                                                            </>
                                                                    }


                                                                </div>
                                                            </div>
                                                        </JarvisWedgit>

                                                    </Dialog>










                                                    <Dialog
                                                        sx={{
                                                            '& .MuiDialog-paperWidthSm': {
                                                                maxWidth: "50%",
                                                                width: "30%",
                                                                minWidth: "650px",
                                                            }

                                                        }}

                                                        onClose={() => { setShowCancelModal(false) }} open={showCancelModal}>
                                                        <JarvisWedgit editbutton={false} deletebutton={false} colorbutton={false}
                                                            togglebutton={false} fullscreenbutton={false} color="blueDark">

                                                            <header className='mainJarvisWedgit__header'>
                                                                <div className='jarvisWedgit__title fontMedium' style={{ width: "100%", textAlign: "start" }}>
                                                                    {_translate("cargo_release.details.cancel_shares_modal.title")}
                                                                </div>

                                                            </header>

                                                            <div>

                                                                <div className="d-flex align-items-center m-3">
                                                                    <div className="col-xs-12 col-sm-12 col-md-12 col-lg-12  autoCompleteLabel">
                                                                        {_translate(
                                                                            "cargo_release.details.cancel_shares_modal.confirmation_message"
                                                                        )}
                                                                    </div>
                                                                    {/* <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                        <FormControl fullWidth>
                                                                            <TextField

                                                                                size="small"
                                                                                onChange={(event) => {
                                                                                    console.log(event.target.value)
                                                                                    if (isNaN(Number(event.target.value))) {
                                                                                        setNumberOfAddedShares(numberOfAddedShares)
                                                                                    }
                                                                                    else {
                                                                                        setNumberOfAddedShares(event.target.value)
                                                                                    }

                                                                                }}
                                                                                onBlur={(event) => { }}
                                                                                value={numberOfAddedShares}
                                                                            />
                                                                        </FormControl>

                                                                    </Box> */}



                                                                </div>


                                                                <div className=" col-xs-12 col-sm-12 col-md-12 col-lg-12  d-flex " style={{ justifyContent: "space-evenly", marginBottom: "2%" }}>
                                                                    {

                                                                        cancelSharesLoadingIndicator ?
                                                                            <Box
                                                                                sx={{
                                                                                    display: "flex",
                                                                                    justifyContent: "center",
                                                                                    alignItems: "center",
                                                                                    // height: "75vh",
                                                                                }}
                                                                            >
                                                                                <CircularProgress />
                                                                            </Box>
                                                                            :
                                                                            <>
                                                                                <Button
                                                                                    sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                    variant="contained"
                                                                                    className=" mt-1"
                                                                                    onClick={() => {
                                                                                        cancelShares()
                                                                                    }}
                                                                                >
                                                                                    {" "}
                                                                                    {_translate("cargo_release.details.cancel_shares_modal.cancel_shares")}
                                                                                </Button>

                                                                                <Button
                                                                                    sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                    variant="contained"
                                                                                    className=" mt-1"
                                                                                    color="error"
                                                                                    onClick={() => {
                                                                                        setShowCancelModal(false)
                                                                                    }}
                                                                                >
                                                                                    {" "}
                                                                                    {_translate("cargo_release.details.cancel_shares_modal.cancel")}
                                                                                </Button>
                                                                            </>
                                                                    }


                                                                </div>
                                                            </div>
                                                        </JarvisWedgit>

                                                    </Dialog>

                                                    <Dialog
                                                        sx={{
                                                            '& .MuiDialog-paperWidthSm': {
                                                                maxWidth: "50%",
                                                                width: "30%",
                                                                minWidth: "650px",
                                                            }

                                                        }}

                                                        onClose={() => { setShowActivationModal(false) }} open={showActivationModal}>
                                                        <JarvisWedgit editbutton={false} deletebutton={false} colorbutton={false}
                                                            togglebutton={false} fullscreenbutton={false} color="blueDark">

                                                            <header className='mainJarvisWedgit__header'>
                                                                <div className='jarvisWedgit__title fontMedium' style={{ width: "100%", textAlign: "start" }}>
                                                                    {_translate("cargo_release.details.activation_modal.title")}
                                                                </div>

                                                            </header>

                                                            <div>

                                                                <div className="d-flex align-items-center m-3">
                                                                    <div className="col-xs-5 col-sm-5 col-md-5 col-lg-5 autoCompleteLabel">
                                                                        {_translate(
                                                                            "cargo_release.details.activation_modal.company"
                                                                        )} :
                                                                    </div>
                                                                    <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                        <FormControl fullWidth>
                                                                            <Select
                                                                                className={clasess.mui_select}
                                                                                value={selectedCompanyForActivation ? selectedCompanyForActivation.value : ""}
                                                                                onChange={(event) => {
                                                                                    setSelectedCompanyForActivation(event.target)
                                                                                    console.log(event.target.value, "event.target")
                                                                                }}
                                                                            >
                                                                                {projectTc ?
                                                                                    projectTc.map((ele) => {
                                                                                        return (
                                                                                            <MenuItem value={ele.id} name={ele.name} >
                                                                                                {ele.name}
                                                                                            </MenuItem>
                                                                                        );
                                                                                    })
                                                                                    : null}
                                                                            </Select>
                                                                        </FormControl>
                                                                    </Box>
                                                                </div>



                                                                <div className="d-flex align-items-center m-3">
                                                                    <div className="col-xs-5 col-sm-5 col-md-5 col-lg-5  autoCompleteLabel">
                                                                        {_translate(
                                                                            "cargo_release.details.activation_modal.shares"
                                                                        )} :
                                                                    </div>
                                                                    <Box className="col-xs-7 col-sm-7 col-md-7 col-lg-7 p-0">
                                                                        <FormControl fullWidth>
                                                                            <TextField

                                                                                size="small"
                                                                                onChange={(event) => {
                                                                                    console.log(event.target.value)
                                                                                    if (isNaN(Number(event.target.value))) {
                                                                                        setNumberOfSharesForActivation(numberOfSharesForActivation)
                                                                                    }
                                                                                    else {
                                                                                        setNumberOfSharesForActivation(event.target.value)
                                                                                    }




                                                                                }}
                                                                                onBlur={(event) => { }}
                                                                                value={numberOfSharesForActivation}
                                                                            />
                                                                        </FormControl>

                                                                    </Box>


                                                                </div>




                                                                <FormGroup >
                                                                    <FormControlLabel className=' mt-1 ml-3 mr-3 mb-3 ' control={<Checkbox onChange={(e) => setReassigneSharesForAvtivation(e.target.checked)} />} label={_translate("cargo_release.details.activation_modal.reassign")} sx={{ fontWeight: 900 }} />
                                                                </FormGroup>




                                                                <div className=" col-xs-12 col-sm-12 col-md-12 col-lg-12  d-flex " style={{ justifyContent: "space-evenly", marginBottom: "2%" }}>
                                                                    {

                                                                        activateCargoReleaseLoadingIndicator ?
                                                                            <Box
                                                                                sx={{
                                                                                    display: "flex",
                                                                                    justifyContent: "center",
                                                                                    alignItems: "center",
                                                                                    // height: "75vh",
                                                                                }}
                                                                            >
                                                                                <CircularProgress />
                                                                            </Box>
                                                                            :
                                                                            <>
                                                                                <Button
                                                                                    sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                    variant="contained"
                                                                                    className=" mt-1"
                                                                                    onClick={() => {
                                                                                        activateCargoRelease()
                                                                                    }}
                                                                                >
                                                                                    {" "}
                                                                                    {_translate("cargo_release.details.activation_modal.activate")}
                                                                                </Button>

                                                                                <Button
                                                                                    sx={{ fontWeight: "900", fontSize: "100%" }}
                                                                                    variant="contained"
                                                                                    className=" mt-1"
                                                                                    color="error"
                                                                                    onClick={() => {
                                                                                        setShowActivationModal(false)
                                                                                        resetActivationModalFeilds()
                                                                                    }}
                                                                                >
                                                                                    {" "}
                                                                                    {_translate("cargo_release.details.activation_modal.cancel")}
                                                                                </Button>
                                                                            </>
                                                                    }


                                                                </div>
                                                            </div>
                                                        </JarvisWedgit>

                                                    </Dialog>























































                                                </>
                                                : null
                                        }

                                        {

                                        }

                                    </>
                            )

































































                            :




                            <div style={{
                                display: "flex",
                                justifyContent: "center",
                                alignItems: "center",
                                height: "75vh",
                            }} >
                                {_translate("permit.cargo_release.details.select_cargo_release_message")}

                            </div>
                        }
                    </div>
                }

            </JarvisWedgit>



        </div >
    )
}




