import React, { useState, useEffect, useContext } from 'react';
import List from '@mui/material/List';
import ListItem from '@mui/material/ListItem';
import Divider from '@mui/material/Divider';
import ListItemText from '@mui/material/ListItemText';
import ListItemAvatar from '@mui/material/ListItemAvatar';
import Avatar from '@mui/material/Avatar';
import Typography from '@mui/material/Typography';
import JarvisWedgit from "../../../components/jarvisWedgit/index"
import { t as _translate } from "i18next"
import LazyLoad from "react-lazy-load";
import WebSckeleton from "../../../components/sckeltonLoadingIndecator/webListSckeleton"
import { CargoReleaseContext } from "../cargoReleaseContext"
import CalendarMonthIcon from "@mui/icons-material/CalendarMonth";
import axios from "../../../config/axios/axios"
import SearchBarDropDown from "../../../components/searchDropDown/searchDropDown";
import Button from "@mui/material/Button";
import Snackbar from '@mui/material/Snackbar';
import MuiAlert from '@mui/material/Alert';
import ActionToolBar from "../../../components/ActionToolBar/actionToolBar"

export default function AlignItemsList() {
    const Alert = React.forwardRef(function Alert(props, ref) {
        return <MuiAlert elevation={6} ref={ref} variant="filled" {...props} />;
    });
    const [closeSearchBar, setCloseSearchBar] = useState(false);
    const [searchFields, setSearchFields] = useState({});
    const [cargoReleaseList, setCargoReleaseList] = useState(null)
    const [basicSearch, setBasicSearch] = useState(null)
    const [loading, setLoading] = useState(false)
    const [alertMessage, setAlertMessage] = useState(null)
    const [openAlert, setOpenAlert] = useState(false)
    const [refresh, setRefresh] = useState(false)

    const changeCloseSearchBar = (close) => {
        setCloseSearchBar(close);
    };
    const onAdvanceSearchChange = (key, value) => {
        setSearchFields({ ...searchFields, [key]: value });

        // this.setState({ [key]: value });
    };
    const clearAndSearch = () => {
        // if (!basicSearch) {
        //     setOpenAlert(true)
        //     setAlertMessage({ message: _translate("cargo_release.list.search_bar.note_message"), type: "warning" })
        //     return
        // }
        // this.setState({ containerList: [] }, (newData) => {
        //   this.setState({ offset: 0 }, (newOffset) => {
        //     this.getContanireList(newData, newOffset)
        //   })
        // })
        searchCargoRelease();
    };
    const onKeyPress = (e) => {
        if (e.key === "Enter") {
            clearAndSearch();
        }
    };

    useEffect(() => {
        searchCargoRelease();
    }, [refresh]);

    const onCloseAlert = () => {
        setOpenAlert(false)
    }
    const onRefresh = () => {
        cargoReleaseContext.selectCargoRelease(null);
        setBasicSearch("")
        setRefresh(!refresh)
    }
    const searchCargoRelease = () => {
        setLoading(true)
        let params = {
            method: "searchCargoRelease",
            filter: {}
        };
        if (basicSearch) {
            params.filter.serial = basicSearch
            params.filter = JSON.stringify(params.filter)
        }
        axios.get("/permit", { params: params }).then((res) => {
            setLoading(false)
            setCargoReleaseList(res.data.data);
            cargoReleaseContext.selectCargoRelease(null);
        }).catch((error) => {
            setLoading(false)
            console.log(error)
            setOpenAlert(true)
            setAlertMessage({ message: error.response.data.MESSAGE, type: "error" })
        })
    };

    let sckeletonArray = [1, 2, 3, 4, 5]
    const cargoReleaseContext = useContext(CargoReleaseContext)
    return (
        <div className="jarvisBody__contiener"
            style={{ height: window.innerHeight - 50, margin: "0", width: "100%" }}>


            <JarvisWedgit editbutton={false} deletebutton={false} colorbutton={false}
                togglebutton={false} fullscreenbutton={false} color="blueDark">

                <header className='mainJarvisWedgit__header'>
                    <div className='jarvisWedgit__title fontMedium'>
                        {_translate("permit.cargo_release.list.title")}
                    </div>
                    <ActionToolBar
                        onRefresh={onRefresh}
                    />


                </header>

                <div style={{ height: "87%" }} >
                    {
                        // alertMessage ?
                        <Snackbar open={openAlert} autoHideDuration={6000} onClose={onCloseAlert}>
                            <Alert severity={alertMessage ? alertMessage.type : null} sx={{ width: '100%' }}>
                                {alertMessage ? alertMessage.message : ""}
                            </Alert>
                        </Snackbar>
                        // : null
                    }

                    <div className='cargoRelease__list--searchContainer' >

                        <SearchBarDropDown
                            style={{ margin: "0" }}
                            closeSearchBar={closeSearchBar}
                            changeCloseSearchBar={changeCloseSearchBar}

                            onChange={(e) => {
                                setBasicSearch(e.target.value)
                            }}
                            placeholder={_translate("cargo_release.list.search_placeholder")}
                            searchValue={basicSearch}
                            readOnly={false}
                            onKeyPress={onKeyPress}
                        ></SearchBarDropDown>
                        {/* <Button
                            sx={{ fontWeight: "900", fontSize: "100%" }}
                            variant="contained"
                            // className=" mt-1"
                            onClick={() => {
                                clearAndSearch()
                            }}
                        >
                            {" "}
                            {_translate("cargo_release.list.search_button")}
                        </Button> */}

                    </div>
                    {

                        cargoReleaseList && !loading ?
                            <div style={{padding:"0 1%", overflow: "auto", height: "100%", marginTop: "1vh" }}>


                                {
                                    cargoReleaseList.length == 0 ?

                                        <div style={{
                                            display: "flex",
                                            justifyContent: "center",
                                            alignItems: "center",
                                            height: "75vh",
                                            fontWeight:"900"

                                        }}>
                                            {_translate("cargo_release.list.no_cargo_release_message")}
                                        </div>
                                        :
                                        cargoReleaseList.map(ele => {

                                            return (
                                                <LazyLoad height={90} >
                                                    <ListItem
                                                        className={`cargoReleaseList__cargoReleaseContainer boxShadowForCards ${cargoReleaseContext.selectedCargoRelease == ele.id ? "selectedBoxShadow" : ""}`}
                                                        onClick={() => {
                                                            cargoReleaseContext.selectCargoRelease(ele.id);
                                                        }}
                                                        sx={{ height: "100%" }}
                                                    >
                                                        <div className="cargoReleaseList__serialNumContainer col-md-3 col-sm-3 col-lg-3 col-xs-3 ">


                                                            <div className="cargoReleaseList__standerdCard" style={{ backgroundColor: "#b994cd91" }}>
                                                                <div className="cargoRelease__number">{ele.serial}</div>

                                                                <div>

                                                                    {ele.details ? JSON.parse(ele.details).issuer : ""}
                                                                </div>
                                                            </div>

                                                        </div>
                                                        <Divider
                                                            orientation="vertical"
                                                            sx={{
                                                                borderRightWidth: "medium",
                                                            }}
                                                            flexItem
                                                        />
                                                        <div className="col-md-9 col-sm-9 col-lg-9 col-xs-9 p-0 pr-2 h-100">
                                                            <ListItemText
                                                                className="cargoReleaseList__cargoReleaseDescriptionDirection m-0  h-100"
                                                                secondary={
                                                                    <React.Fragment>

                                                                        <div
                                                                            style={{
                                                                                display: "flex",
                                                                                flexDirection: "column",
                                                                                height: "100%"
                                                                            }}
                                                                        >
                                                                            <div className="col-md-12 col-sm-12 col-lg-12 col-xs-12 p-0 d-flex justify-content-between    h-100">
                                                                                <div className="col-md-9 col-sm-9 col-lg-9 col-xs-9 cargoReleaseCard__info  h-100">
                                                                                    <div>
                                                                                        {_translate("cargo_release.list.card.shares")} : {ele.shares}
                                                                                    </div>
                                                                                    <div>
                                                                                        {_translate("cargo_release.list.card.cargo_name")} : {ele.cargo ? JSON.parse(ele.cargo).name : null}
                                                                                    </div>

                                                                                </div>
                                                                                <div className="d-flex flex-column col-md-3 col-sm-3 col-lg-3 col-xs-3  p-0  h-100" style={{ justifyContent: "space-around" }}>
                                                                                    <div className="cargoReleaseList__standerdCard d-flex ">
                                                                                        <CalendarMonthIcon
                                                                                            sx={{ fontSize: "1rem" }}
                                                                                        />{" "}
                                                                                        {(ele.create_date).slice(0, 10)}
                                                                                    </div>
                                                                                    <div
                                                                                        className="cargoReleaseList__standerdCard "
                                                                                        style={{
                                                                                            background: "#eee",

                                                                                        }}
                                                                                    >
                                                                                        {_translate(`cargo_release.list.card.statues.${ele.status}`)}

                                                                                    </div>

                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </React.Fragment>
                                                                }
                                                            />
                                                        </div>
                                                    </ListItem>
                                                </LazyLoad>
                                            )

                                        })
                                }
                            </div>
                            :
                            sckeletonArray.map(ele => {
                                return (
                                    <div>
                                        <WebSckeleton />
                                    </div>
                                )
                            })
                    }
                </div>



            </JarvisWedgit>
        </div>
    );
}
